@@ -43,10 +43,9 @@ subsetDBs <- function(dbs, universe) {
 
 
 guess_dbnames <- function(
-        nms, platform = NULL,allow_multi = FALSE, type = NULL,
-        silent = FALSE) {
+        nms, platform = NULL,allow_multi = FALSE, silent = FALSE) {
 
-    gps <- listDBGroups(type = type)
+    gps <- listDBGroups()
     nms <- do.call(c, lapply(nms, function(nm) {
         if (nm %in% gps$Title) {
             return(nm)
@@ -68,30 +67,15 @@ guess_dbnames <- function(
         nms <- grep(platform, nms, value = TRUE)
     }
     if (!silent) {
-        message("Selected the following database groups:")
-        invisible(lapply(seq_along(nms), function(i) {
-            message(sprintf("%d. %s", i, nms[i]))
-        }))
+        if (length(nms) == 0) {
+            message("No knowledgebase selected. Please reselect.")
+        } else {
+            message("Selected the following database groups:")
+            invisible(lapply(seq_along(nms), function(i) {
+                message(sprintf("%d. %s", i, nms[i]))
+            }))
+        }
     }
     nms
 }
 
-## internal
-loadDBs <- function(in_paths) {
-    if (length(in_paths)==1 && dir.exists(in_paths)) {
-        groupnms <- list.files(in_paths)
-        in_paths <- file.path(in_paths, groupnms)
-    } else {
-        groupnms <- basename(in_paths)
-    }
-    do.call(c, lapply(seq_along(groupnms), function(i) {
-        tbl <- read.table(in_paths[i],sep="\t",header=TRUE)
-        dbs <- split(tbl$Probe_ID, tbl$Knowledgebase)
-        lapply(names(dbs), function(dbname) {
-            db1 <- dbs[[dbname]];
-            attr(db1, "group") <- sub(".gz$","",groupnms[i]);
-            attr(db1, "dbname") <- dbname;
-            db1;})
-    }))
-}
-
