@@ -34,6 +34,31 @@ dbs <- getDBs("MM285.design")
 ## ----ky7, view-data1, eval=TRUE, warning=FALSE--------------------------------
 str(dbs[["PGCMeth"]])
 
+## ----ky7b, eval=FALSE---------------------------------------------------------
+# # Load ImprintingDMR database from Zenodo
+# dbs_imprinting <- readRDS(url(paste0(
+#     "https://zenodo.org/records/18344496/files/",
+#     "KYCG.HM450.ImprintingDMR.20220818.rds")))
+# 
+# # Examine the loaded database
+# str(dbs_imprinting)
+
+## ----ky7c, eval=FALSE---------------------------------------------------------
+# # Load multiple databases from Zenodo
+# 
+# urls <- paste0(
+#     "https://zenodo.org/records/18344496/files/",
+#     c("KYCG.HM450.ImprintingDMR.20220818.rds",
+#         "KYCG.HM450.Blacklist.20220304.rds"))
+# 
+# dbs_multiple <- do.call(c, lapply(urls, function(x) readRDS(url(x))))
+# 
+# # Examine the loaded database
+# str(dbs_multiple)
+# 
+# # Use these databases in enrichment testing
+# results <- testEnrichment(query, dbs_multiple, platform="HM450")
+
 ## ----ky8, run-test-single, echo=TRUE, eval=TRUE, message=FALSE----------------
 library(SummarizedExperiment)
 
@@ -75,19 +100,19 @@ results <- testEnrichment(query,databases=dbs,
 main_stats <- c("dbname","estimate","gene_name","FDR", "nQ", "nD", "overlap")
 results[,main_stats] %>% head()
 
-## ----ky12, message=FALSE------------------------------------------------------
-## prepare query probes
-df <- rowData(sesameData::sesameDataGet('MM285.tissueSignature'))
-query_probes <- df$Probe_ID[df$branch == "fetal_liver" & df$type == "Hypo"]
-
-## link them to genes
-genes <- linkProbesToProximalGenes(query_probes, platform = "MM285")$gene_name
-
-## use gprofiler2 to test enrichment
-library(gprofiler2)
-gostres <- gprofiler2::gost(genes, organism = "mmusculus")
-head(gostres$result[order(gostres$result$p_value),])
-
+## ----ky12, message=FALSE, eval=FALSE------------------------------------------
+# ## prepare query probes
+# df <- rowData(sesameData::sesameDataGet('MM285.tissueSignature'))
+# query_probes <- df$Probe_ID[df$branch == "fetal_liver" & df$type == "Hypo"]
+# 
+# ## link them to genes
+# genes <- linkProbesToProximalGenes(query_probes, platform = "MM285")$gene_name
+# 
+# ## use gprofiler2 to test enrichment
+# library(gprofiler2)
+# gostres <- gprofiler2::gost(genes, organism = "mmusculus")
+# head(gostres$result[order(gostres$result$p_value),])
+# 
 
 ## ----ky13, eval = TRUE,message=FALSE------------------------------------------
 df <- rowData(sesameDataGet('MM285.tissueSignature'))
@@ -95,6 +120,6 @@ probes <- df$Probe_ID[df$branch == "fetal_liver" & df$type == "Hypo"]
 res <- testProbeProximity(probeIDs=probes)
 head(res)
 
-## -----------------------------------------------------------------------------
+## ----session-info-------------------------------------------------------------
 sessionInfo()
 
